.. NeoBase documentation master file, created by
   sphinx-quickstart on Thu Jan 14 10:03:07 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NeoBase's documentation!
===================================

.. automodule:: neobase.neobase
    :members:
    :special-members: __init__
    :undoc-members:
    :show-inheritance:
